# Agent Data Readiness Index (ADRI)

[![PyPI version](https://badge.fury.io/py/adri.svg)](https://badge.fury.io/py/adri)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![GitHub Pages](https://img.shields.io/badge/Docs-GitHub%20Pages-blue)](https://probable-adventure-3jve6ry.pages.github.io/)

**Stop Your AI Agents from Flying Blind!**

Agentic AI systems often fail because they can't "see" the quality of the data they rely on. They might trust stale, incomplete, or inconsistent information, leading to costly mistakes and unreliable behavior. This is **Agent Data Blindness**.

**ADRI is the solution:** An open standard and toolkit designed to evaluate how well data sources communicate their quality attributes *to AI agents*. Think of it as providing **"Data Nutrition Labels"** for your agent's data sources.

ADRI assesses data across five key dimensions (Validity, Completeness, Freshness, Consistency, Plausibility), focusing specifically on whether quality signals are available and understandable *by the agent*.

## Key Features

*   **Standardized Score (0-100):** Quickly gauge data readiness for agentic use.
*   **Actionable Insights:** Get specific findings and recommendations to fix data blindness issues.
*   **Extensible Framework:** Add custom connectors for your data sources and new quality dimensions.
*   **AI Framework Integrations:** Easily integrate ADRI checks into LangChain, DSPy, CrewAI, and other workflows.
*   **Community Catalog:** Contribute to and explore a growing catalog of ADRI assessments for common public datasets.

## Quick Install

```bash
pip install adri
```

## Learn More & Get Involved

**Visit our main documentation site for:**

*   **Full Installation & Usage Guides**
*   **Detailed Methodology & Scoring**
*   **Framework Integration Examples**
*   **Community Dataset Catalog**
*   **Contribution Guidelines**
*   **And much more!**

➡️ **Visit our documentation site: [ADRI Documentation](https://probable-adventure-3jve6ry.pages.github.io/)**

Join the movement to build more reliable and trustworthy AI agents!

## License

This project is licensed under the MIT License. See the [LICENSE](LICENSE) file for details.
